@@ -33,7 +33,6 @@ namespace bareFTP.Preferences.Bookmarks
 		Config conf;
 		XmlDocument bookmarks;
 		private bool use_keyring;
-		private bool convert = false;
 		
 		public Bookmarks()
 		{
@@ -159,6 +158,10 @@ namespace bareFTP.Preferences.Bookmarks
 						entry.ShowHidden = bool.Parse(el.SelectSingleNode("showhidden").InnerText);
 						entry.Passive = bool.Parse(el.SelectSingleNode("passive").InnerText);
 						entry.EncryptData = el.SelectSingleNode("encryptdata").InnerText;
+						if(el.SelectSingleNode("syncronized_browse") != null)
+							entry.SyncedBrowse = bool.Parse(el.SelectSingleNode("syncronized_browse").InnerText);
+						else
+							entry.SyncedBrowse = false;
 						folder.Items.Add(entry);
 					}
 				}
